%=============================================================
%        Exemple de code pour la 1re partie du TPA05 :
%   ACP applique  des moyennes mensuelles de tempratures
%   locales (9 villes) pour les mois de la priode 1982 - 2010.
%   Pour cette 1re partie, les variables sont les villes, et
%   les mois sont les individus.
%   Vous pouvez choisir les axes  utiliser pour les cercles 
%   de corrlations et les nuages des individus en affectant
%   les variables cpa et cpb dans le code.
clear; close all; clc
%================================================================
% LES DONNEES (priode 1/1982  12/2010) and some Init
%----------------------------------------------------------------
% Chargement des donnes 
load clim_t2C_J1982D2010; % Temperature at 2 meters (degC)  
%
% The variable it-self
X     = clim_t2(:,3:end);
[Ndata, NbVar] = size(X); % dimensions
%
% Pour l'identification des variables-villes, des individus-mois
lieux = {'Reykjavik','Oslo','Paris','New York','Tunis','Alger','Beyrouth','Atlan','Dakar'};
individus = cellstr(num2str(clim_t2(:,2)));  % les mois
%
% Pour la labellisation par les individus de l'axe des x avec les annes (au mois de janvier)
Ilab = find(clim_t2(:,2)==1);   % Indices des mois de janvier
Xlab = clim_t2(Ilab,1);         % On rcupre les annes de ces indices
%
% Un tableau de couleurs des courbes par villes
colvil = jet(NbVar);            
colvil(4,:)=[0 0.5 0];
colvil(5,:)=[0 1.0 0];
%
%================================================================
% 1) Affichages sur les donnes brutes 
%-------------------------------------------------------------
% 1.1) Visualisation Courbes des donnes brutes (par ville)
%plotclimt2(clim_t2);
figure; hold on
for i=1:NbVar; 
    plot(clim_t2(:,i+2), 'color',colvil(i,:),'linewidth',1.5); 
end
axis tight;
% Habillage de la figure :
set(gca,'XTick',Ilab, 'XTickLabel',Xlab); 
title('Tempratures (t2 en degrs Celsius) par ville');
legend(lieux);
%
% 1.2) Courbes des moyennes et carts types
figure;
subplot(2,1,1); plot(mean(X),'-*b'); 
set(gca,'XTick',[1:NbVar]','XTickLabel',lieux);
xlabel('Moyennes'); axis tight;
subplot(2,1,2); plot(std(X),'-*g');
set(gca,'XTick',[1:NbVar]','XTickLabel',lieux);
xlabel('Ecarts types'); axis tight;
%
%================================================================
% 2) Analyse en Composantes Principales
%----------------------------------------------------------------
% Normalisation des donnes par centrage rduction
XN = centred(X,mean(X),std(X)); 
%
% Calcul de l'ACP
if (exist('OCTAVE_VERSION'))
   [VEPU, CP, VAP] = ocp(XN);
else
   [VEPU, CP, VAP, TSQUARE] = princomp(XN);
end
%
%----------------------------------------------------------------
% 2.1) Pourcentage d'inertie et d'inertie cumulee des valeurs propres
phinertie(VAP); 
%
% Choix des axes de plan principaux
cpa=1; cpb=2; 
%
%----------------------------------------------------------------
% 2.2) Contribution des individus  la formation des axes (CTR)
% Calcul des contributions 
CTR = (1/(size(CP,1)-1))*(CP.^2) ./ (ones(size(CP,1),1)*VAP');
%
% Affichage des contributions 
figure; hold on
subplot(2,1,1); plot(CTR(:,cpa),'-b','linewidth',1.5); 
legend(['axe',num2str(cpa)]); axis tight;
subplot(2,1,2); plot(CTR(:,cpb),'-g','linewidth',1.5);
legend(['axe',num2str(cpb)]);  axis tight;
set(gca,'XTick',Ilab, 'XTickLabel',Xlab);
title(sprintf('Contribution des individus  la fabrication des axes%i et %i', cpa,cpb));
%
%----------------------------------------------------------------
% 2.3) Cercle de corrlation : Corrlation des variables avec les
% composantes principales (pour des donnes centres et rduites)
%----------------------------------------------------------------
corcer(XN,CP,cpa,cpb,lieux);
set(gcf,'color','w');
title(sprintf('Cercle des corrlations des variables avec les axes principaux %i et %i',cpa,cpb));
%
%----------------------------------------------------------------
% 2.4) Nuage des individus-mois, avec :
% - chelle de couleur en fonction de la temprature moyenne
% - taille des marqueurs proportionne  la qualit de reprsentation
% - labellisation par le mois de l'individu
%---------------------------------------------------------------
% Temprature moyennes en chelle de couleur
t2moy = mean(clim_t2(:,3:end),2);
%
% Qualit de reprsentation
dist = (sum((CP').^2))';
QLT = (CP.^2) ./ (dist*ones(1,size(CP,2)));
%
% Nuage des individus
acpnuage(CP,cpa,cpb,t2moy,individus,QLT,20); 
title(sprintf('Nuage des individus sur le plan des axes principaux %i et %i\nEch.col : Tempratures moyennes mensuelles', cpa,cpb));
%
%---------------------------------------------------------------
% 2.5) Courbes des climatologies de temprature mensuelle par ville
%----------------------------------------------------------------
% Calcul de la climatologie (moyenne des mois) des tempratures par ville 
for m=1:12
    Imonth = find(clim_t2(:,2)==m);
    Xm(m,:) = mean(XN(Imonth,:)); 
end
%
figure; hold on
Col = jet(NbVar); % Table de couleur
% Labelisation des mois
monthlab={'janv','fv','mars','avril','mai','juin','juil','aout','sept','oct','nov','dc',};
%
% Affichage des courbes sur la figure, ville par ville
for vil=1:NbVar
    plot(Xm(:,vil),'-*', 'color',Col(vil,:),'linewidth',2.0);
end
set(gca,'XTick',[1:12], 'XTickLabel',monthlab);
legend(lieux); axis tight
title('Courbes des climatologies (moyennes des mois) de la temprature par ville (donnes normalises)');
%
%----------------------------------------------------------------
% 2.6) (re) Nuage des individus-mois, avec :
% - chelle de couleur en fonction du CO2 corrig de sa tendance globale
% - labellisation par le mois de l'individu
%---------------------------------------------------------------
% Calcul du CO2 corrig par la pente de rgression
load clim_co2_J1982D2010; % co2 molfrac en ppm (partie par million) de 1/1982  12/2010
tclim = [1:Ndata]';                       % Les pas de temps
[b0,b1] = regtrace(tclim,clim_co2(:,3));  % rgression du co2 
co2cor  = clim_co2(:,3) - b1*tclim ;      % correction du co2
%
% Nuage des individus
acpnuage(CP,cpa,cpb,co2cor,individus); 
title(sprintf('Nuage des individus sur le plan des axes principaux %i et %i\n Ech.col : CO2 corrig', cpa,cpb));
%
%================================================================
