%=============================================================
%        Exemple de code pour la 2me partie du TPA05 :
%   ACP applique  des moyennes mensuelles de tempratures
%   locales (9 villes) pour les mois de la priode 1982 - 2010.
%   Pour cette 2me partie, les donnes seront transposes, ce
%   qui revient  intervertir le role des mois et des ville; 
%   c'est  dire que les variables sont les mois, et les villes 
%   sont les individus.
%   Vous pouvez choisir les axes  utiliser pour les cercles 
%   de corrlations et les nuages des individus en affectant
%   les variables cpa et cpb dans le code.
clear; close all; clc
%================================================================
% LES DONNEES (priode 1/1982  12/2010) and some Init
%----------------------------------------------------------------
% Chargement des donnes 
load clim_t2C_J1982D2010; % fichier des temperature at 2 metres (degC)  
X = clim_t2(:,3:end);     % Les valeurs proprement dit
%
% Transposition de donnes pour avoir les individus-villes 
% en ligne et les variables-mois en colonne
Y = X';
[Ndata, NbVar] = size(Y); % dimensions
%
% Normalisation par centrage et rduction
YN = centred(Y,mean(Y),std(Y));  % centrer et rduire
%
%----------------------------------------------------------------
% Diverses initialisation
%
% Pour l'identification des individus-villes, des variables-mois
lieux = {'Reykjavik','Oslo','Paris','New York','Tunis','Alger','Beyrouth','Atlan','Dakar'};
individus = lieux;
%
% Pour la labellisation par les individus de l'abscisse
Ilab = [1:Ndata]';
Xlab = lieux';
%
% Labelisation des mois
monthlab={'janv','fv','mars','avril','mai','juin','juil','aout','sept','oct','nov','dc',};
%
% Tableau des couleurs des courbes par villes
colvil = jet(Ndata);            
colvil(4,:)=[0 0.5 0];
colvil(5,:)=[0 1.0 0];
%
% Tableau des couleurs des courbes par villes
colmois = colmois;
%
%================================================================
% 1.1) Courbes des donnes (serie chronologique) de chaque ville
%----------------------------------------------------------------
%plotclimt2(clim_t2);
% Labelisation de l'abscisse par l'anne ( chaque 1er janvier)
Ilabj = find(clim_t2(:,2)==1);  % Indices des mois de janvier
Xlaba = clim_t2(Ilabj,1);       % On rcupre les annes de ces indices
%
% Visualisation des donnes brutes :
figure; hold on
for i=1:Ndata; 
    plot(clim_t2(:,i+2), 'color',colvil(i,:),'linewidth',1.5); 
end
axis tight;
% Habillage de la figure :
set(gca,'XTick',Ilabj, 'XTickLabel',Xlaba); 
title('Tempratures (t2 en degrs Celsius) par ville');
legend(lieux);
%_______________________________________
% Visualisation des donnes Centres rduites (par mois) :
figure; hold on
for i=1:Ndata; plot(YN(i,:), 'color',colvil(i,:),'linewidth',1.5); end 
axis tight;
% - Habillage de la figure :
set(gca,'XTick',Ilabj, 'XTickLabel',Xlaba); 
title('Tempratures t2 normalises par mois');
legend(lieux);
%_______________________________________
% Coefficients des pentes
fprintf('Coefficients des pentes de regression \n Villes    s/donnes brutes   s/donnes normalises\n');
for i=1:Ndata;
   [nop, b1] = regtrace([1:NbVar],Y(i,:)); 
   [nop, b1N]= regtrace([1:NbVar],YN(i,:)); 
   fprintf('%9s        %f          % f \n', lieux{i}, b1, b1N);
end
%
%================================================================
% 2) Analyse en Composantes Principales
%----------------------------------------------------------------
if (exist('OCTAVE_VERSION'))
   [VEPU, CP, VAP] = ocp(YN);
else
   [VEPU, CP, VAP, TSQUARE] = princomp(YN);
end
%
%================================================================
% 2.1) Pourcentage d'inertie et d'inertie cumulee des valeurs propres
phinertie(VAP);
%
% Choix des axes de plan principaux
cpa=1; cpb=2; 
%
%----------------------------------------------------------------
% 2.2) Cercle de corrlation : Coordonnes des variables-mois 
%        dans les plans principaux
%
% Affichage des cercles de corrlations des variables sur le plan choisi
variables = repmat(monthlab,1,29);
corcer(YN,CP,cpa,cpb,variables,colmois,1);
title(sprintf('Cercles des corrlations des variables avec les axes principaux %i et %i',cpa,cpb));
%
corcer(YN,CP,cpa,cpb,variables,colmois,2); 
%
corcer(YN,CP,cpa,cpb,variables,colmois,3);
title(sprintf('Cercles des corrlations : Vecteurs moyens mensuels sur les axes principaux %i et %i',cpa,cpb));
%
%----------------------------------------------------------------
% 2.3) Qualit de representation (QLT) et Contribution (CTR)
[QLT, CTR] = qltctr(CP,VAP);
%
% Affichage des contributions
figure; hold on
subplot(2,1,1); plot(CTR(:,cpa),'-b','linewidth',1.5); 
legend(['axe',num2str(cpa)]); axis tight;
subplot(2,1,2); plot(CTR(:,cpb),'-g','linewidth',1.5);
legend(['axe',num2str(cpb)]); axis tight;
set(gca,'XTick',Ilab, 'XTickLabel',Xlab);
title(sprintf('Contribution des individus  la fabrication des axes%i et %i',cpa,cpb));
%
%+ en clair pour les axes choisis
lieux, contribution=CTR(:,[cpa,cpb])', 
%sum(CTR(:,[cpa,cpb])) % 2 check=100 ou 1.00 ?
%
%----------------------------------------------------------------
% 2.4) Nuage des individus-villes :
% Scatter plot 2D des individus sur 2 axes principaux avec qualit 
% de reprsentation (QLT). 
%---------------------------------------------------------------
acpnuage(CP,cpa,cpb,[],individus,QLT,20); 
title(sprintf('Nuage des individus plan %i, %i (taille en proportion de la qualit de reprsentation)', cpa,cpb));
%+ en clair pour les axes choisis ?
lieux, qualite=QLT(:,[cpa,cpb])', 
%_______________________________________
% Comparaison par ville : donnes brutes, moyennes, et cp1
fp=figure; hold on; set(fp,'color','w')
for m=1:12
    Imonth = find(clim_t2(:,2)==m);
    plot(Y(:,Imonth), 'color',colmois(m,:));
end
colormap(colmois); hc=colorbar;
if (exist('OCTAVE_VERSION'))
   set(hc,'YTick',[0.05:(0.95-0.05)/11:0.95]','YTickLabel',monthlab,'fontweight','bold'); 
else
   set(hc,'YTick',[1.5:1:12.5]'); set(hc,'YTickLabel',monthlab,'fontweight','bold');
end
% + Valeur Moyenne par ville
moyX=mean(X);
plot(moyX','k','linewidth',3);
axis tight
set(gca,'XTick',Ilab, 'XTickLabel',Xlab,'fontweight','bold');
title('Courbes des tempratures brutes par mois et courbe  moyenne par ville (en noir)',...
      'fontweight','bold', 'fontsize',12);
%
% Premire Composante Principale
figure; hold on
plot(CP(:,cpa),'-*','linewidth',1.5); axis tight;
xlabel(['axe' int2str(cpa)]);
set(gca,'XTick',Ilab, 'XTickLabel',Xlab);
%
r=corrcoef([CP(:,cpa), moyX']);
title(sprintf('%ire composante principale\n(Corrlation  la moyenne r=%f)',cpa,r(1,2)));
%_______________________________________
% Moyenne par ville des tempratures t2 brutes par mois
figure; hold on
for i=1:Ndata; %pour chaque ville
    for mm=1:12;
        Im = find(clim_t2(:,2)==mm);
        moy = mean(clim_t2(Im,i+2));
        Tmv(mm,i) = moy;
    end
    plot(Tmv(:,i), 'color',colvil(i,:),'linewidth',1.5);
end
axis tight;
set(gca,'XTick',[1:12], 'XTickLabel',monthlab); 
title('Moyenne par ville des tempratures t2 brutes par mois');
%
% On ajoute la moyenne mois
moymois = mean(Tmv,2);
plot(moymois, '-k','linewidth',2.5);
legend([lieux {'moyenne'}]);
%
%_______________________________________
% Moyenne par ville des tempratures t2 normalises par mois
figure; hold on
for i=1:Ndata; %pour chaque ville
    for mm=1:12;
        Im = find(clim_t2(:,2)==mm);
        Tmoy(mm) = mean(YN(i,Im)); % moyenne du mois mm pour la ville i
    end
    plot(Tmoy,'-*','color',colvil(i,:),'linewidth',1.5);
end
axis tight;
set(gca,'XTick',[1:12], 'XTickLabel',monthlab); 
title('Moyennes mensuelles par ville des tempratures t2 normalises par mois');
legend(lieux);
%
%===============================================================
%

